@@ -20,7 +20,7 @@
 #'  will default to -1e+10.
 #' @param start_upper upper boundaries for the start parameters. If missing, this
 #'  will default to 1e+10.
-#' @param supp_errors if \code{supp_errors = 'Y'}, then no error messages from
+#' @param supp_errors if \code{supp_errors = 'Y'}, then warning messages will be suppressed and no error messages from
 #' \code{\link[minpack.lm]{nlsLM}} will be shown, reducing the number of error messages printed while the model attempts to converge using poor starting parameters.
 #' We advise to only use \code{supp_errors = 'Y'} when confident in the bounds of
 #'  your starting parameters.
@@ -137,6 +137,12 @@ nls_multstart <-
     # transform input arguments
     silent <- ifelse(supp_errors == "Y", TRUE, FALSE)
 
+    # if silent is TRUE, temporarily switch off warnings
+    if(silent == TRUE){
+      oo <- options(warn=-1)
+      on.exit(options(oo))
+    }
+
     if ("modelweights" %in% all.vars(formula)) {
       stop(paste0(
         "The variable name 'modelweights' is reserved for model weights. Please change the name\n",
@@ -213,6 +219,7 @@ nls_multstart <-
         start.vals <- as.list(strt[j, ])
 
         # try and fit the model for every set of searching parameters
+
         try(
           fit <- minpack.lm::nlsLM(
             formula,
